@@ -97,6 +97,7 @@ $lang['additional_title'] = 'Additional content to appear in head';
 $lang['stylesheet_title'] = 'Include &#123;cms_stylesheet} tag';
 $lang['stylesheet_name'] = 'Name parameter';
 $lang['stylesheet_nocombine'] = 'No Combine parameter';
+$lang['stylesheet_nolinks'] = 'No Links parameter';
 $lang['stylesheet_https'] = 'Use https url';
 $lang['stylesheet_templateid'] = 'Template ID parameter';
 $lang['stylesheet_media'] = 'Media parameter';
@@ -248,7 +249,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.9.6 11 April 2013. Added the option to choose robots meta and Twitter card and Google+ profile page links.</li>
 <li>Version 1.9.7 18 April 2013. Content block variables now appear in order in the description tag, appended by the content of the default Content block by default.</li>
 <li>Version 1.9.8 22 April 2013. Added support for Google Universal Analytics.</li>
-<li>Version 1.9.9 30 April 2013. Added the ability to disable/enable keywords tag.</li></ul>';
+<li>Version 1.9.9 30 April 2013. Added the ability to disable/enable keywords tag.</li>
+<li>Version 1.9.9.1 2 May 2013. Minor bug fixes.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
